Getting Started
===============

There are currently two categories of tools:

- Gizmos
- Scripts

Getting started is easy. After you have installed The Silo, all available tools
will be added to a menu called ``The Silo`` and sub-menus called ``Gizmos`` and
``Scripts``. That's it. :)
